# arpes.preparation.coord\_preparation module

**arpes.preparation.coord\_preparation.replace\_coords(arr:
xarray.core.dataarray.DataArray, new\_coords,
mapping)**

**arpes.preparation.coord\_preparation.disambiguate\_coordinates(datasets,
possibly\_clashing\_coordinates)**
